@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.2
-id: yesod-1.4.2-920710b39b065bda5684c54c5a6f5e49
-key: yesod_IxSnnVp0a4HGIxaJIvMRvu
+id: yesod-1.4.2-76e8368576238ae2e4cea7b46d440834
+key: yesod_4pbIxlaw7ptLfhJrH20oez
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,37 +21,37 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.2
-hs-libraries: HSyesod-1.4.2-IxSnnVp0a4HGIxaJIvMRvu
+hs-libraries: HSyesod-1.4.2-4pbIxlaw7ptLfhJrH20oez
 depends:
-    aeson-0.10.0.0-b63a88a6e7bf231c11601ff561c0eb0d
+    aeson-0.10.0.0-d37842f030fec47bc6e0ba2aef0f6571
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-html-0.8.1.1-b598557be4ce3598e270c7592be1f33c
-    blaze-markup-0.7.0.3-adfaa12a6c8f95338d1eda4a379eb541
+    blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
+    blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-extra-1.1.9.2-1bef4166ec3f53ae2e6d2e9011cd9cbe
+    conduit-extra-1.1.9.2-fc66bf7a229ea809b0bdda20349fc384
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
-    fast-logger-2.4.1-3a82ef8da5665c7f13125a65809925c9
+    fast-logger-2.4.1-72875ca91290e61690089a3e7f5d8466
     monad-control-1.0.0.4-fa18b603f1c859e06ea8fbebdf00a3e7
-    monad-logger-0.3.17-6bebcabc98fb90582d59aab2ac8cf400
+    monad-logger-0.3.17-5a437bc25b12232eea72a7824921b81a
     safe-0.3.9-b613242f536083d5bb04920ede356aea
-    semigroups-0.18.0.1-09717ed0a84e1dbeffebbb54d604d271
-    shakespeare-2.0.7-00dfbe294be5d21a7267aeab62f6403d
-    streaming-commons-0.1.15-bfe5dd5a0dc219d23135213ca9f37753
+    semigroups-0.18.0.1-8982ad8edd41304214263f489c2b00c2
+    shakespeare-2.0.7-3d8247ff57d7f10558308bd73d118ae2
+    streaming-commons-0.1.15-43ddfb983feecf5e5c9c7ab99b5e44ed
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
-    text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
+    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
-    unordered-containers-0.2.6.0-08e36bb27daebf8e082345cc5a0772e7
-    wai-3.2.0-a50c1f56084e726fac99a6d8758a9179
-    wai-extra-3.0.13.1-1bc7c4095875bfb4df8293ce63574926
-    wai-logger-2.2.4.1-529e83bc9ac8fd22414c4cbc982c9843
-    warp-3.2.1-90add4f6b8b8590f7d734b50560a29dd
-    yaml-0.8.15.3-35e7f7b998eff49fb5374e4dc80a0cb1
-    yesod-auth-1.4.11-997100edb3e04364a3e6730f77e6a38f
-    yesod-core-1.4.18.1-1427f09c60204e2c904ad1c11de4a4ba
-    yesod-form-1.4.6-46903ec6bcb029c9002a4483982ff868
-    yesod-persistent-1.4.0.3-6906742652c1a7fb4b32fa3f8904977c
+    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
+    wai-3.2.0-ef5213f36cb00369a3d68c2dd00424b9
+    wai-extra-3.0.13.1-314c5124cb0852313c04571c3b3ec596
+    wai-logger-2.2.4.1-78754ae80b1823d94a638e54c94b2c6e
+    warp-3.2.1-8f9aad771e0c137389da779f459b244d
+    yaml-0.8.15.3-ab552a8419b21afe9697730ec885ddb9
+    yesod-auth-1.4.11-29ac9496af34049748a4c0630a909e57
+    yesod-core-1.4.18.1-d7e104254067d78d775739267f9cb9c0
+    yesod-form-1.4.6-92ff325373223eae289777f4741b01f3
+    yesod-persistent-1.4.0.3-2e529d161a2b1535593d72ef006de97b
 haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
 haddock-html: /usr/share/doc/haskell-yesod/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
